@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 
     Authors: Ettore Perazzoli <ettore@helixcode.com>
 */
@@ -28,12 +28,14 @@
 #include <glib/gi18n.h>
 #endif
 
-#include <gnome.h>
+#include <libgnomeui/gnome-ui-init.h>
+#include <libgnomeui/gnome-app-helper.h>
 #include <bonobo.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
- 
+#include <unistd.h>
+
 #include <glib.h>
 #include <Editor.h>
 #include "editor-control-factory.h"
@@ -132,7 +134,7 @@ save_through_plain_persist_stream (const gchar *filename,
 
 		stream_mem = BONOBO_STREAM_MEM (stream);
 		text = g_byte_array_new ();
-		g_byte_array_append (text, stream_mem->buffer, stream_mem->pos);
+		g_byte_array_append (text, (guint8 *) stream_mem->buffer, stream_mem->pos);
 		bonobo_object_unref (BONOBO_OBJECT (stream));
 
 		fd = creat (filename, 0622);
@@ -196,27 +198,6 @@ enum _FileSelectionOperation {
 };
 typedef enum _FileSelectionOperation FileSelectionOperation;
 
-struct _FileSelectionInfo {
-	BonoboWidget *control;
-	GtkWidget *widget;
-
-	FileSelectionOperation operation;
-};
-typedef struct _FileSelectionInfo FileSelectionInfo;
-
-static FileSelectionInfo file_selection_info = {
-	NULL,
-	NULL,
-	OP_NONE
-};
-
-static void
-file_selection_destroy_cb (GtkWidget *widget,
-			   gpointer data)
-{
-	file_selection_info.widget = NULL;
-}
-
 static void
 view_source_dialog (BonoboWindow *app, char *type, gboolean as_html)
 {
@@ -239,7 +220,7 @@ view_source_dialog (BonoboWindow *app, char *type, gboolean as_html)
 	gtk_widget_show_all (window);
 
 	g_signal_connect_swapped (control, "destroy", G_CALLBACK (gtk_widget_destroy), window);
-}    
+}
 
 static void
 view_html_source_cb (GtkWidget *widget,
@@ -262,95 +243,84 @@ view_html_source_html_cb (GtkWidget *widget,
 	view_source_dialog (data, "text/html", TRUE);
 }
 
+
 static void
-file_selection_cancel_cb (GtkWidget *widget, gpointer data)
-{
-	gtk_widget_destroy (GTK_WIDGET (data));
-}
-
-static void
-file_selection_ok_cb (GtkWidget *widget,
-		      gpointer data)
+open_or_save_as_dialog (BonoboWindow *app,
+			FileSelectionOperation operation)
 {
 	CORBA_Object interface;
 	const gchar *interface_name;
 	CORBA_Environment ev;
+	GtkWidget *widget;
+	BonoboWidget *control;
+	gchar *filename;
 
-	if (file_selection_info.operation == OP_SAVE_THROUGH_PERSIST_FILE
-	    || file_selection_info.operation == OP_LOAD_THROUGH_PERSIST_FILE)
+	control = BONOBO_WIDGET (bonobo_window_get_contents (app));
+
+	if (operation == OP_LOAD_THROUGH_PERSIST_FILE ||
+			operation == OP_LOAD_THROUGH_PERSIST_STREAM)
+		widget = gtk_file_chooser_dialog_new (
+			_("Open file..."), GTK_WINDOW (app),
+			GTK_FILE_CHOOSER_ACTION_OPEN,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			GTK_STOCK_OPEN, GTK_RESPONSE_APPLY,
+			NULL);
+	else
+		widget = gtk_file_chooser_dialog_new (
+			_("Save file as..."), GTK_WINDOW (app),
+			GTK_FILE_CHOOSER_ACTION_SAVE,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			GTK_STOCK_SAVE, GTK_RESPONSE_APPLY,
+			NULL);
+
+	if (gtk_dialog_run (GTK_DIALOG (widget)) == GTK_RESPONSE_CANCEL)
+		goto exit;
+
+	if (operation == OP_SAVE_THROUGH_PERSIST_FILE ||
+			operation == OP_LOAD_THROUGH_PERSIST_FILE)
 		interface_name = "IDL:Bonobo/PersistFile:1.0";
 	else
 		interface_name = "IDL:Bonobo/PersistStream:1.0";
 
 	CORBA_exception_init (&ev);
-	interface = Bonobo_Unknown_queryInterface (bonobo_widget_get_objref (file_selection_info.control),
-						   interface_name, &ev);
+	interface = Bonobo_Unknown_queryInterface (
+		bonobo_widget_get_objref (control), interface_name, &ev);
 	CORBA_exception_free (&ev);
 
 	if (interface == CORBA_OBJECT_NIL) {
-		g_warning ("The Control does not seem to support `%s'.", interface_name);
-	} else 	 {
-		const gchar *fname;
-
-		fname = gtk_file_selection_get_filename
-			(GTK_FILE_SELECTION (file_selection_info.widget));
-
-		switch (file_selection_info.operation) {
-		case OP_LOAD_THROUGH_PERSIST_STREAM:
-			load_through_persist_stream (fname, interface);
-			break;
-		case OP_SAVE_THROUGH_PERSIST_STREAM:
-			save_through_persist_stream (fname, interface);
-			break;
-		case OP_SAVE_THROUGH_PLAIN_PERSIST_STREAM:
-			save_through_plain_persist_stream (fname, interface);
-			break;
-		case OP_LOAD_THROUGH_PERSIST_FILE:
-			load_through_persist_file (fname, interface);
-			break;
-		case OP_SAVE_THROUGH_PERSIST_FILE:
-			save_through_persist_file (fname, interface);
-			break;
-		default:
-			g_assert_not_reached ();
-		}
-	} 
-
-	gtk_widget_destroy (file_selection_info.widget);
-}
-
-
-static void
-open_or_save_as_dialog (BonoboWindow *app,
-			FileSelectionOperation op)
-{
-	GtkWidget    *widget;
-	BonoboWidget *control;
-
-	control = BONOBO_WIDGET (bonobo_window_get_contents (app));
-
-	if (file_selection_info.widget != NULL) {
-		gdk_window_show (GTK_WIDGET (file_selection_info.widget)->window);
-		return;
+		g_warning (
+			"The Control does not seem to support `%s'.",
+			interface_name);
+		goto exit;
 	}
 
-	if (op == OP_LOAD_THROUGH_PERSIST_FILE || op == OP_LOAD_THROUGH_PERSIST_STREAM)
-		widget = gtk_file_selection_new (_("Open file..."));
-	else
-		widget = gtk_file_selection_new (_("Save file as..."));
+	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (widget));
 
-	gtk_window_set_transient_for (GTK_WINDOW (widget),
-				      GTK_WINDOW (app));
+	switch (operation) {
+	case OP_LOAD_THROUGH_PERSIST_STREAM:
+		load_through_persist_stream (filename, interface);
+		break;
+	case OP_SAVE_THROUGH_PERSIST_STREAM:
+		save_through_persist_stream (filename, interface);
+		break;
+	case OP_SAVE_THROUGH_PLAIN_PERSIST_STREAM:
+		save_through_plain_persist_stream (filename, interface);
+		break;
+	case OP_LOAD_THROUGH_PERSIST_FILE:
+		load_through_persist_file (filename, interface);
+		break;
+	case OP_SAVE_THROUGH_PERSIST_FILE:
+		save_through_persist_file (filename, interface);
+		break;
+	default:
+		;
+		//g_assert_not_reached ();
+	}
 
-	file_selection_info.widget = widget;
-	file_selection_info.control = control;
-	file_selection_info.operation = op;
+	g_free (filename);
 
-	g_signal_connect (GTK_FILE_SELECTION (widget)->cancel_button, "clicked", G_CALLBACK (file_selection_cancel_cb), widget);
-	g_signal_connect (GTK_FILE_SELECTION (widget)->ok_button, "clicked", G_CALLBACK (file_selection_ok_cb), NULL);
-	g_signal_connect (file_selection_info.widget, "destroy", G_CALLBACK (file_selection_destroy_cb), NULL);
-
-	gtk_widget_show (file_selection_info.widget);
+exit:
+	gtk_widget_destroy (widget);
 }
 
 /* "Open through persist stream" dialog.  */
@@ -435,7 +405,7 @@ menu_format_html_cb (BonoboUIComponent           *component,
 }
 
 /* A dirty, non-translatable hack */
-static char ui [] = 
+static char ui [] =
 "<Root>"
 "	<commands>"
 "	        <cmd name=\"FileExit\" _label=\"Exit\" _tip=\"Exit the program\""
@@ -567,18 +537,18 @@ main (int argc, char **argv)
 	bindtextdomain(GTKHTML_RELEASE_STRING, GNOMELOCALEDIR);
 	textdomain(GTKHTML_RELEASE_STRING);
 
-	gnome_program_init("test-editor", VERSION, LIBGNOMEUI_MODULE, argc, argv, 
+	gnome_program_init("test-editor", VERSION, LIBGNOMEUI_MODULE, argc, argv,
 			   GNOME_PROGRAM_STANDARD_PROPERTIES,
-			   GNOME_PARAM_HUMAN_READABLE_NAME, _("GtkHTML Editor Test Container"),			   
+			   GNOME_PARAM_HUMAN_READABLE_NAME, _("GtkHTML Editor Test Container"),
 			   NULL);
 
 	bonobo_activate ();
 
 	/* We can't make any CORBA calls unless we're in the main loop.  So we
 	   delay creating the container here. */
-	gtk_idle_add ((GtkFunction) container_create, NULL);
+	g_idle_add ((GtkFunction) container_create, NULL);
 	if (argc > 1 && *argv [argc - 1] != '-')
-		gtk_idle_add ((GtkFunction) load_file, argv [argc - 1]);
+		g_idle_add ((GtkFunction) load_file, argv [argc - 1]);
 
 	bonobo_activate ();
 	bonobo_main ();
