@@ -39,7 +39,6 @@ struct _GtkHTMLPrivate {
 
 	gint selection_type;
 
-	gchar *content_type;
 	char  *base_url;
 
 	GtkWidget *search_input_line;
@@ -76,6 +75,8 @@ struct _GtkHTMLPrivate {
 	gboolean in_url_test_mode;
 
 	gboolean in_key_binding;
+
+	char *caret_first_focus_anchor;
 };
 
 void  gtk_html_private_calc_scrollbars  (GtkHTML                *html,
