@@ -273,6 +273,29 @@ op_copy (HTMLObject *self, HTMLObject *parent, HTMLEngine *e, GList *from, GList
 	return dup;
 }
 
+static HTMLAnchor *
+find_anchor (HTMLObject *self, const char *name, gint *x, gint *y)
+{
+	HTMLIFrame *iframe;
+	HTMLAnchor *anchor;
+
+	g_return_val_if_fail (HTML_IS_IFRAME (self), NULL);
+
+	iframe = HTML_IFRAME (self);
+
+	if (!iframe || !iframe->html || !GTK_IS_HTML (iframe->html) || !GTK_HTML (iframe->html)->engine || !GTK_HTML (iframe->html)->engine->clue)
+		return NULL;
+
+	anchor = html_object_find_anchor (GTK_HTML (iframe->html)->engine->clue, name, x, y);
+
+	if (anchor) {
+		*x += self->x;
+		*y += self->y - self->ascent;
+	}
+
+	return anchor;
+}
+
 void
 html_iframe_set_margin_width (HTMLIFrame *iframe, gint margin_width)
 {
@@ -588,7 +611,11 @@ html_iframe_init (HTMLIFrame *iframe,
 	new_tokenizer = NULL;
 
 	gtk_html_set_default_content_type (new_html,
-					   parent_html->priv->content_type);
+					   gtk_html_get_default_content_type(parent_html));
+
+	gtk_html_set_default_engine (new_html,
+					   gtk_html_get_default_engine(parent_html));
+					   
 	iframe->html = new_widget;
 	iframe->url = g_strdup (src);
 	iframe->width = width;
@@ -623,10 +650,10 @@ html_iframe_init (HTMLIFrame *iframe,
 	 * proxied like url_requested is.
 	 */
 	gtk_signal_connect (GTK_OBJECT (new_html), "on_url",
-			    GTK_SIGNAL_FUNC (iframe_on_url),
+			    G_CALLBACK (iframe_on_url),
 			    (gpointer)iframe);
 	gtk_signal_connect (GTK_OBJECT (new_html), "link_clicked",
-			    GTK_SIGNAL_FUNC (iframe_link_clicked),
+			    G_CALLBACK (iframe_link_clicked),
 			    (gpointer)iframe);
 #endif
 	g_signal_connect (new_html, "size_changed", G_CALLBACK (iframe_size_changed), iframe);
@@ -635,7 +662,7 @@ html_iframe_init (HTMLIFrame *iframe,
 
 	/*
 	  gtk_signal_connect (GTK_OBJECT (html), "button_press_event",
-	  GTK_SIGNAL_FUNC (iframe_button_press_event), iframe);
+	  G_CALLBACK (iframe_button_press_event), iframe);
 	*/
 
 	gtk_widget_set_size_request (scrolled_window, width, height);
@@ -654,13 +681,13 @@ html_iframe_init (HTMLIFrame *iframe,
 	html_painter_set_focus (new_html->engine->painter, parent_html->engine->have_focus);
 	/*
 	gtk_signal_connect (GTK_OBJECT (html), "title_changed",
-			    GTK_SIGNAL_FUNC (title_changed_cb), (gpointer)app);
+			    G_CALLBACK (title_changed_cb), (gpointer)app);
 	gtk_signal_connect (GTK_OBJECT (html), "button_press_event",
-			    GTK_SIGNAL_FUNC (on_button_press_event), popup_menu);
+			    G_CALLBACK (on_button_press_event), popup_menu);
 	gtk_signal_connect (GTK_OBJECT (html), "redirect",
-			    GTK_SIGNAL_FUNC (on_redirect), NULL);
+			    G_CALLBACK (on_redirect), NULL);
 	gtk_signal_connect (GTK_OBJECT (html), "object_requested",
-			    GTK_SIGNAL_FUNC (object_requested_cmd), NULL);
+			    G_CALLBACK (object_requested_cmd), NULL);
 	*/
 }
 
@@ -706,6 +733,7 @@ html_iframe_class_init (HTMLIFrameClass *klass,
 	object_class->check_point             = check_point;
 	object_class->is_container            = is_container;
 	object_class->append_selection_string = append_selection_string;
+	object_class->find_anchor             = find_anchor;
 
 	embedded_class->reparent = reparent;
 }
